#
# spec file for package gstreamermm
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	soname	-1_0-1
%define sover   1
%define _sver   1.10
%define _mver   1.0
Name:           gstreamermm
Version:        1.10.0
Release:        bp154.2.142
Summary:        C++ bindings for the GStreamer streaming multimedia library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://gstreamer.freedesktop.org/bindings/cplusplus.html
Source0:        https://ftp.gnome.org/pub/gnome/sources/gstreamermm/%{_sver}/%{name}-%{version}.tar.xz
Source99:       %{name}-rpmlintrc

# PATCH-FIX-UPSTREAM gstreamermm-copy_metadata_vfunc.patch bgo#794249 -- Fix bug tied to copy_metadata_vfunc
Patch0:         gstreamermm-copy_metadata_vfunc.patch
# PATCH-FIX-UPSTREAM gstreamermm-copy_metadata_vfunc.patch bgo#794250 -- Fix bug tied to copy_metadata_vfunc
Patch1:         gstreamermm-copy_metadata_vfunc2.patch
# PATCH-FIX-UPSTREAM gstreamermm-copy_metadata_vfunc.patch -- Fix bug tied to copy_metadata_vfunc
Patch2:         gstreamermm-copy_metadata_vfunc3.patch
# PATCH-FIX-UPSTREAM gstreamermm-non-volatile.patch dimstar@opensuse,org -- Fix build with glib 2.68
Patch3:         gstreamermm-non-volatile.patch

BuildRequires:  Mesa-libGLESv2-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(giomm-2.4)
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-allocators-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-app-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-audio-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-base-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-check-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-controller-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-fft-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-net-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-riff-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-rtp-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-rtsp-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-sdp-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-tag-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-video-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gtkmm-3.0) >= 3.0
BuildRequires:  pkgconfig(libxml++-3.0)

%description
gstreamermm provides C++ bindings for the GStreamer streaming multimedia
library (http://gstreamer.freedesktop.org).  With gstreamermm it is possible to
develop applications that work with multimedia in C++.

%package        devel
Summary:        C++ bindings for the GStreamer streaming multimedia library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}

%description    devel
gstreamermm provides C++ bindings for the GStreamer streaming multimedia
library (http://gstreamer.freedesktop.org).  With gstreamermm it is possible to
develop applications that work with multimedia in C++.

%package        doc
Summary:        C++ bindings for the GStreamer streaming multimedia library
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
gstreamermm provides C++ bindings for the GStreamer streaming multimedia
library (http://gstreamer.freedesktop.org).  With gstreamermm it is possible to
develop applications that work with multimedia in C++.

%package     -n lib%{name}%{soname}
Summary:        C++ bindings for the GStreamer streaming multimedia library
Group:          System/Libraries

%description -n lib%{name}%{soname}
gstreamermm provides C++ bindings for the GStreamer streaming multimedia
library (http://gstreamer.freedesktop.org).  With gstreamermm it is possible to
develop applications that work with multimedia in C++.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files devel
%license COPYING
%doc ChangeLog README
%{_includedir}/%{name}-%{_mver}
%{_libdir}/%{name}-%{_mver}
%{_libdir}/lib%{name}-%{_mver}.so
%{_libdir}/pkgconfig/%{name}-%{_mver}.pc

%files doc
%license COPYING
%{_datadir}/devhelp/books/%{name}-%{_mver}
%{_datadir}/doc/%{name}-%{_mver}

%files -n lib%{name}%{soname}
%license COPYING
%{_libdir}/lib%{name}-%{_mver}.so.%{sover}*

%changelog
* Tue Jul 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add gstreamermm-non-volatile.patch: Fix build with glib 2.68.
* Fri Feb 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Replace libxml++-devel, gtkmm3-devel, gstreamer-devel and
  gstreamer-plugin-base-devel with pkgconfig(libxml++-3.0),
  pkgconfig(gtkmm-3.0), pkgconfig(gstreamer-1.0) and
  pkgconfig(gstreamer-plugins-base-1.0) BuildRequires. Also add
  all the gstreamer .pc symboles configure checks for:
  pkgconfig(gstreamer-allocators-1.0),
  pkgconfig(gstreamer-app-1.0), pkgconfig(gstreamer-audio-1.0),
  pkgconfig(gstreamer-base-1.0), pkgconfig(gstreamer-check-1.0),
  pkgconfig(gstreamer-controller-1.0),
  pkgconfig(gstreamer-fft-1.0), pkgconfig(gstreamer-net-1.0),
  pkgconfig(gstreamer-pbutils-1.0), pkgconfig(gstreamer-riff-1.0),
  pkgconfig(gstreamer-rtp-1.0), pkgconfig(gstreamer-rtsp-1.0),
  pkgconfig(gstreamer-sdp-1.0), pkgconfig(gstreamer-tag-1.0) and
  pkgconfig(gstreamer-video-1.0).
- Drop unneeded Requires from devel subpackage.
- Modernize spec, update URL.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace glibmm2-devel with pkgconfig and pkgconfig(giomm-2.4)
  BuildRequires: Ensure we only pull in one and the correct
  glibmm-devel package.
- Drop unneeded hard glibmm2-devel Requires from devel sub-package.
* Sat Jun 23 2018 bjorn.lie@gmail.com
- Add gstreamermm-copy_metadata_vfunc.patch,
  gstreamermm-copy_metadata_vfunc2.patch and
  gstreamermm-copy_metadata_vfunc3.patch: Fix several bugs tied to
  copy_metadata_vfunc (bgo#794249, bgo#794250).
* Sat Oct 28 2017 aloisio@gmx.com
- Spec cleanup
* Sat Oct 21 2017 aloisio@gmx.com
- Update to version 1.10.0
  * Remove gstreamermm-plugins-bad experimental module
  * Deprecate plugins API
  * Add more examples
  * Implement GstNetClientClock wrapper
  * Add GstSDPMedia wrapper
- Dropped gstreamermm-1.8.0-build_with_gst_1.12.0.patch and
  gstreamermm-1.8.0-fix_gcc7_build.patch (merged upstream)
- Spec cleanup
* Mon Jul 10 2017 jengelh@inai.de
- Fix RPM groups.
* Sun Jul  2 2017 aloisio@gmx.com
- Update to version 1.8.0
  * Wrap more methods and classes
  * Fix base plugin classes
  * Review Gst::Structure and Gst::Caps API
  * Add multiple examples, tests
  * Enable C++11 interface
- Dropped 01-disable-tests.patch and
  02-do-not-compile-examples.patch and replaced them with a
  shell command
- Dropped 03-fix-ftbfs.patch (merged upstream)
- Added gstreamermm-1.8.0-build_with_gst_1.12.0.patch and
  gstreamermm-1.8.0-fix_gcc7_build.patch
- Added gstreamermm-rpmlintrc
* Tue Sep 27 2016 xrigou@otenet.gr
- Disable building the tests and examples
- Fix compiler error in Tumbleweed
* Sat Nov 28 2015 xrigou@otenet.gr
- Updated to version 1.4.3
* Sun May 10 2015 xrigou@otenet.gr
- Renamed package to upstream name
- Updated to version 1.0.10
- Spec clean-up
* Thu Oct 24 2013 xrigou@otenet.gr
- Updated to version 0.10.11
* Thu Sep  6 2012 xgpub@tellas.gr
- Updated to version 0.10.10.2
- Build for openSUSE 12.2
* Sat Nov 19 2011 xgpub@tellas.gr
- Updated to version 0.10.10
* Sat Apr 16 2011 xgpub@tellas.gr
- Updated to version 0.10.8
* Mon Nov 29 2010 xgpub@tellas.gr
- new package branched from home:ars3niy
- Updated to version 0.10.7
- Fixed gcc 4.5 compilation errors.
- Disabled static build
- Fixed some rpmlint warnings
